#
# spec file for package usbmuxd
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#



Name:           usbmuxd
%define _libname   libusbmuxd
Version:        1.0.7
Release:        3.3.1
License:        LGPL v2.1 or GPL v2
Summary:        Socket daemon for the usbmux protocol of iPhone/iPod Touch devices
Url:            http://git.marcansoft.com/?p=usbmuxd.git
Group:          System/Libraries
Source:         %{name}-%{version}.tar.bz2
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  libplist-devel
BuildRequires:  libusb-1_0-devel >= 1.0.3
BuildRequires:  pkg-config
BuildRequires:  udev
Requires(pre):  pwdutils
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This package provides the usbmuxd daemon for software to use through the
libusbmuxd library to talk with iPhone/iPod Touch devices.

Usbmux is an encapsulation protocol (think IP, ATM, PPP) that allows
multiplexing several conversations onto a single pair of wires.

%package -n %{_libname}1


License:        LGPL v2.1 or GPL v2
Summary:        A library to abstract socket/protocol communication to the usbmuxd daemon
Group:          System/Libraries
Requires:       %{name}
Provides:       %{_libname} = %{version}
Obsoletes:      %{_libname} < %{version}

%description -n %{_libname}1
This package contains the libusbmuxd library which provides an interface to
talk to the usbmux daemon, create connections and list attached devices.

%package -n %{_libname}-devel


Summary:        Development files for %{_libname}
Group:          Development/Libraries/C and C++
Requires:       %{_libname} = %{version}
Requires:       glibc-devel

%description -n %{_libname}-devel
The %{_libname}-devel package contains libraries and header files for
developing applications that use %{_libname}.

%package -n iproxy
License:        LGPL v2.1 or GPL v2
Summary:        Proxy enabling TCP tunneling to iPhone/iPod Touch via USB cable
Group:          System/Libraries
Requires:       %{_libname} = %{version}

%description -n iproxy
Proxy enabling TCP tunneling to iPhone/iPod Touch via USB cable.

It allows you to map a port of a service running on the device (like sshd) and
redirect it to your local machine where you can interact with it.

%pre
getent passwd usbmux >/dev/null || useradd -r -g nogroup -d /var/lib/%{name} -s /sbin/nologin -c "%{name} daemon" usbmux
exit 0

%prep
%setup -q

%build
mkdir build
cd build
export CFLAGS="%{optflags} -fno-strict-aliasing"
cmake -DBUILD_STATIC_LIBS:BOOL=OFF -DCMAKE_INSTALL_PREFIX=%{_prefix} \
%if "%{_lib}" == "lib64"
      -DLIB_SUFFIX:STRING=64 \
%endif
      -DCMAKE_VERBOSE_MAKEFILE=TRUE \
      -DCMAKE_C_FLAGS_RELEASE:STRING="%{optflags}" \
      -DCMAKE_CXX_FLAGS_RELEASE:STRING="%{optflags}" \
      -DCMAKE_BUILD_TYPE=Release \
      -DCMAKE_SKIP_RPATH=1 \
      -DBUILD_TESTING=OFF \
%if %{undefined suse_version}
      -DCMAKE_INSTALL_DO_STRIP=1 \
%endif
      ..
make %{?_smp_mflags}

%install
cd build
%{__make} install DESTDIR=%{buildroot}
# make sure the device gets owned by the usbmux user
sed -i 's@RUN+="/usr/sbin/usbmuxd -u -U usbmux"@OWNER="usbmux", RUN+="/usr/sbin/usbmuxd -u -U usbmux"@' %{buildroot}/lib/udev/rules.d/85-usbmuxd.rules

%clean
rm -rf %{buildroot}

%post -n %{_libname}1 -p /sbin/ldconfig

%postun -n %{_libname}1 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc AUTHORS COPYING.GPLv2 COPYING.GPLv3 COPYING.LGPLv2.1 README
%{_sbindir}/usbmuxd
/lib/udev/rules.d/85-usbmuxd.rules

%files -n %{_libname}1
%defattr(-,root,root)
%{_libdir}/libusbmuxd.so.*

%files -n %{_libname}-devel
%defattr(-,root,root,-)
%doc README.devel
%{_includedir}/usbmuxd.h
%{_includedir}/usbmuxd-proto.h
%{_libdir}/%{_libname}.so
%{_libdir}/pkgconfig/%{_libname}.pc

%files -n iproxy
%defattr(-,root,root)
%{_bindir}/iproxy

%changelog
* Thu Mar 24 2011 opensuse@sukimashita.com
- Create and use "usbmux" user in %%pre to fix bno#679159
* Thu Mar 24 2011 opensuse@sukimashita.com
- Update to version 1.0.7
  * Detect iPad 2 and upcoming next generation iPhone devices
  * Fix support for ancient devices running iOS 1.x
  * Optionally use inotify instead of polling to safe energy
* Thu Dec  9 2010 cristian.rodriguez@opensuse.org
- Fix -devel package dependencies, libusb is only required at
  runtime.
- disable static library creation instead of removing it.
* Mon Nov 15 2010 coolo@novell.com
- ran spec-cleaner
* Mon Nov 15 2010 coolo@novell.com
- Update to version 1.0.6
  * Bump udev rules to 0-9a-f, should last for a few device iterations
  * Fix potential issue with USB transactions >=32k multiples of 16k
- remove patch no longer necessary
* Thu Jul 22 2010 opensuse@sukimashita.com
- Update to version 1.0.5
  * Protocol version 1 support. Enables libusbmuxd to talk to
    Apple's official usbmuxd on Windows and OSX
  * Recovery mode support for idevicerestore firmware restores
  * Detach kernel USB drivers to avoid USB issues
  * Win32 support for libusbmuxd
  * FreeBSD support
  * Basic C++ support
  * Fixes crasher bugs
- Added libplist dependancy
- Remove upstreamed patch
* Fri Jun  4 2010 davejplater@gmail.com
- Fixed incorrect summary and description see bnc#611595
* Tue May 11 2010 opensuse@sukimashita.com
- Update to version 1.0.4
  * Fix aborts due to transmit window overflow
  * libusbmuxd: close connection after enumerating devices
  * Ignore SIGPIPE, otherwise usbmuxd might shut down
  * OSX: add workaround for missing ppoll system call
  * Detect the iPad and let usbmuxd talk to it
  * libusbmuxd: support shorter device info record messages
* Tue Mar 23 2010 opensuse@sukimashita.com
- Update to version 1.0.3
  * Set USBMUX_SUPPORTED in udev rules for user space to be
    able to recognize devices supporting the usbmux protocol.
* Thu Feb 11 2010 opensuse@sukimashita.com
- Update to version 1.0.2
  * Change documentation to mention libimobiledevice, add a
    trademark notice, and make things more consistent
  * Security fix: fix a potential buffer overflow that could
    be triggered by a rogue device
  * Fixed a crash when we get unexpected TCP packets early
    (e.g. reconnected device).
  * usbmuxd will not 'drop' privileges to root (-U root is
    now a no-op)
  * Made -U require an argument. The optional argument behavior
    was causing some confusion (since -U <name> didn't work,
    it had to be -U<name>), so now the argument is required.
    Please make sure that you specify an explicit name from now
    on ('-U' will not work).
  * Removed debugging printfs in libusbmuxd
  * Cleaned up and improved CMakeLists. Now it should honor the
    CFLAGS environment variable if it is present and nonempty
  * Add a missing <pthread.h> include to libusbmuxd
* Mon Dec  7 2009 opensuse@sukimashita.com
- Update to version 1.0.0
  * Workaround udev bug; fixes not reacting to signals
  * Do not try to claim all Apple devices
  * Fix libusbmuxd cleanup when usbmuxd shuts down
- Remove upstreamed patches
* Sat Oct 31 2009 opensuse@sukimashita.com
- Update to version 1.0.0-rc2
  * Improved documentation
  * Fix install target for 64bit architectures
  * Fix underlinking of libusbmuxd
* Wed Oct 28 2009 opensuse@sukimashita.com
- Update to version 1.0.0-rc1
  * completly new implementation
  * uses cmake build system
  * improved libusbmuxd API with device hotplug callbacks
  * better performance and lower cpu usage
* Mon Aug 10 2009 opensuse@sukimashita.com
- Update to version 0.1.4
  * udev operation mode
  * better udev rules for non-Debian distributions
  * debugging output refined with a mutex to prevent garbled output
  * smaller buffer size in usbmuxd_client_handler_thread to fix
    connection resets
* Tue Aug  4 2009 opensuse@sukimashita.com
- Update to version 0.1.3
  * Proper fix for USB communication issue using wMaxPacketSize
* Sun Aug  2 2009 opensuse@sukimashita.com
- Update to version 0.1.1
  * Fix USB communication issue with packet sizes of N*128 or N*512
* Mon Jul 20 2009 opensuse@sukimashita.com
- Update to version 0.1.0
  * First official release
  * Adds iPhone 3GS support and exposes new tethering USB interface
  * Fix race condition using multiple clients simultaneously
  * Fix various usbmux protocol bugs
* Fri May 22 2009 opensuse@sukimashita.com
- Initial package created
